==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-et-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Estonian (http://www.transifex.com/tine20/tine20/language/et/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: et\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: ""

, "Standard IMAP"
: ""

, "Standard SMTP"
: ""

, "Imap"
: "Imap"

, "Hostname"
: "Hostinimi"

, "Username"
: "Kasutajanimi"

, "Password"
: "Parool"

, "Port"
: "Port"

, "Secure Connection"
: "Turvaline ühendus"

, "None"
: "Pole"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: ""

, "No"
: "Ei"

, "Yes"
: "Jah"

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Autentimine"

, "Login"
: ""

, "Plain"
: ""

, "Primary Domain"
: ""

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: ""

, "Notification Username"
: ""

, "Notification Password"
: ""

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: "MySql hostinimi"

, "MySql Database"
: "MySql andmebaas"

, "MySql User"
: "MySql kasutaja"

, "MySql Password"
: "MySql parool"

, "MySql Port"
: "MySql port"

, "User or UID"
: "Kasutaja või UID"

, "Group or GID"
: "Grupp või GID"

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: ""

, "PLAIN"
: ""

, "I have read the license agreement and accept it"
: ""

, "License Agreement"
: ""

, "I have read the privacy agreement and accept it"
: ""

, "Privacy Agreement"
: ""

, "Accept Terms and Conditions"
: ""

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: ""

, "Result"
: ""

, "Error"
: ""

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Install application"
: "Paigalda rakendus"

, "File"
: "Fail"

, "Setup Authentication"
: ""

, "Database"
: "Andmebaas"

, "User"
: "Kasutaja"

, "Prefix"
: "Eesliide"

, "Logging"
: "Logimine"

, "Filename"
: "Failinimi"

, "Priority"
: "Tähtsus"

, "Caching"
: "Puhverdamine"

, "Lifetime (seconds)"
: ""

, "Path"
: "Asukoht"

, "Queue"
: ""

, "Session"
: "Sessioon"

, "Temporary files"
: ""

, "Temporary Files Path"
: ""

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: "välja lülitatud"

, "enabled"
: "sisse lülitatud"

, "Config file is not writable"
: ""

, "Save config"
: ""

, "Download config file"
: ""

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: ""

, "Setup Checks"
: ""

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: ""

, "Application Manager"
: ""

, "Delete all existing users and groups"
: ""

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: ""

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: ""

, "Authentication provider"
: ""

, "Try to split username"
: ""

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: "Host"

, "Login name"
: "Kasutajanimi"

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: ""

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: ""

, "Default user group name"
: ""

, "Default admin group name"
: ""

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: ""

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: ""

, "User Filter"
: ""

, "User Search Scope"
: ""

, "Groups DN"
: ""

, "Group Filter"
: ""

, "Group Search Scope"
: ""

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: ""

, "Max User Id"
: ""

, "Min Group Id"
: ""

, "Max Group Id"
: ""

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Passwords don't match"
: ""

, "Should not be empty"
: ""

, "Setup"
: ""

, "Application, Applications"
: [
  ""
 ,""

]
, "Name"
: "Nimi"

, "Enabled"
: "Sisse lülitatud"

, "Order"
: "Järjekord"

, "Installed Version"
: "Paigaldatud versioon"

, "Available Version"
: "Saadaolev versioon"

, "Status"
: "Staatus"

, "Depends on"
: "Sõltub"

, "Uninstall application"
: "Eemalda rakendus"

, "Update application"
: "Uuenda rakendust"

, "Go to {0} login"
: ""

, "uninstall"
: "eemalda"

, "Do you really want to uninstall the application(s)?"
: ""

, "This may take a while"
: "See võib veidi aega võtta"

, "Dependency Violation"
: "Sõltuvuse rikkumine"

, "CLI Required"
: ""

, "Application"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Setup/js/Setup-lang-et-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Estonian (http://www.transifex.com/tine20/tine20/language/et/)\nLanguage: et\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: ""

, "License Agreement"
: ""

, "I have read the privacy agreement and accept it"
: ""

, "Privacy Agreement"
: ""

, "Accept Terms and Conditions"
: ""

, "Backend"
: ""

, "Standard IMAP"
: ""

, "Standard SMTP"
: ""

, "Imap"
: "Imap"

, "Hostname"
: "Hostinimi"

, "Username"
: "Kasutajanimi"

, "Password"
: "Parool"

, "Port"
: "Port"

, "Secure Connection"
: "Turvaline ühendus"

, "None"
: "Pole"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: ""

, "No"
: "Ei"

, "Yes"
: "Jah"

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Autentimine"

, "Login"
: ""

, "Plain"
: ""

, "Primary Domain"
: ""

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: ""

, "Notification Username"
: ""

, "Notification Password"
: ""

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: "MySql hostinimi"

, "MySql Database"
: "MySql andmebaas"

, "MySql User"
: "MySql kasutaja"

, "MySql Password"
: "MySql parool"

, "MySql Port"
: "MySql port"

, "User or UID"
: "Kasutaja või UID"

, "Group or GID"
: "Grupp või GID"

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: ""

, "PLAIN"
: ""

, "Terms and Conditions"
: ""

, "Setup Checks"
: ""

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: ""

, "Application Manager"
: ""

, "Setup"
: ""

, "Name"
: "Nimi"

, "Enabled"
: "Sisse lülitatud"

, "Order"
: "Järjekord"

, "Installed Version"
: "Paigaldatud versioon"

, "Available Version"
: "Saadaolev versioon"

, "Status"
: "Staatus"

, "Depends on"
: "Sõltub"

, "Install application"
: "Paigalda rakendus"

, "Uninstall application"
: "Eemalda rakendus"

, "Update application"
: "Uuenda rakendust"

, "Go to {0} login"
: ""

, "uninstall"
: "eemalda"

, "Do you really want to uninstall the application(s)?"
: ""

, "This may take a while"
: "See võib veidi aega võtta"

, "Dependency Violation"
: "Sõltuvuse rikkumine"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: ""

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: ""

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: ""

, "Authentication provider"
: ""

, "Try to split username"
: ""

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: "Host"

, "Login name"
: "Kasutajanimi"

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: ""

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: ""

, "Default user group name"
: ""

, "Default admin group name"
: ""

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: ""

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: ""

, "User Filter"
: ""

, "User Search Scope"
: ""

, "Groups DN"
: ""

, "Group Filter"
: ""

, "Group Search Scope"
: ""

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: ""

, "Max User Id"
: ""

, "Min Group Id"
: ""

, "Max Group Id"
: ""

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Save config"
: ""

, "Passwords don't match"
: ""

, "Should not be empty"
: ""

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: ""

, "Result"
: ""

, "Error"
: ""

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Application, Applications"
: [
  ""
 ,""

]
, "File"
: "Fail"

, "Setup Authentication"
: ""

, "Database"
: "Andmebaas"

, "User"
: "Kasutaja"

, "Prefix"
: "Eesliide"

, "Logging"
: "Logimine"

, "Filename"
: "Failinimi"

, "Priority"
: "Tähtsus"

, "Caching"
: "Puhverdamine"

, "Lifetime (seconds)"
: ""

, "Path"
: "Asukoht"

, "Queue"
: ""

, "Session"
: "Sessioon"

, "Temporary files"
: ""

, "Temporary Files Path"
: ""

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: "välja lülitatud"

, "enabled"
: "sisse lülitatud"

, "Config file is not writable"
: ""

, "Download config file"
: ""

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
